==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Herhangi bir sonuç bulunamadı</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Diğerleri</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Masaüstünden kaldır</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Görev çubuğundan kaldır</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Vekil sunucu ile aç</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Ekran ölçeklendirmeyi devre dışı bırak</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Masaüstüne gönder</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Görev çubuğuna gönder</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Başlangıçtan kaldır</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Başlangıca ekle</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Tüm Uygulamalar</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Diğerleri</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Tüm bağımlılıklarıyla birlikte kaldırılacak</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotoğraflar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotoğraflar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Kılavuz</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Tüm Kategoriler</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Arama</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Herhangi bir sonuç bulunamadı</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Oyunlar</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Masaüstünden kaldır</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Görev çubuğundan kaldır</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Ekran ölçeklendirmeyi devre dışı bırak</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Masaüstüne gönder</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Görev çubuğuna gönder</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Başlangıçtan kaldır</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Başlangıca ekle</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Tüm Uygulamalar</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Diğerleri</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotoğraflar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Fotoğraflar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirilenler</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Kılavuz</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Görüntüler</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Tüm Kategoriler</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Arama</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?</translation>
    </message>
</context>
</TS>
